@@ -73,7 +73,7 @@ config = {
   'cell_size': 32,
   'lod_cell_height': 128,
   'n_neighbors': 6,
-  'min_dist': 0.001,
+  'min_distance': 0.001,
   'metric': 'correlation',
   'pointgrid_fill': 0.05,
   'square_cells': False,
@@ -203,7 +203,7 @@ def stream_images(**kwargs):
         metadata = kwargs['metadata'][idx]
       yield Image(i, metadata=metadata)
     except Exception as exc:
-      print(' * image', i, 'could not be processed', exc)
+      print(' * image', i, 'could not be processed --', exc)
 
 
 def clean_filename(s):
@@ -483,7 +483,7 @@ def get_umap_layout(**kwargs):
   if os.path.exists(out_path) and kwargs['use_cache']: return out_path
   w = PCA(n_components=100).fit_transform(kwargs['vecs'])
   z = UMAP(n_neighbors=kwargs['n_neighbors'],
-    min_dist=kwargs['min_dist'],
+    min_dist=kwargs['min_distance'],
     metric=kwargs['metric']).fit_transform(w)
   return write_layout(out_path, z, **kwargs)
 
@@ -553,7 +553,8 @@ def get_date_layout(cols=3, bin_units='years', **kwargs):
   @param int cols: the number of columns to plot for each bar
   @param str bin_units: the temporal units to use when creating bins
   '''
-  if not kwargs['metadata'] or not kwargs['metadata'][0].get('date', False): return False
+  date_vals = [kwargs['metadata'][i].get('date', False) for i in range(len(kwargs['metadata']))]
+  if not kwargs['metadata'] or not any(date_vals): return False
   # if the data layouts have been cached, return them
   positions_out_path = get_path('layouts', 'timeline', **kwargs)
   labels_out_path = get_path('layouts', 'timeline-labels', **kwargs)
@@ -963,7 +964,7 @@ def parse():
   parser.add_argument('--out_dir', type=str, default=config['out_dir'], help='the directory to which outputs will be saved', required=False)
   parser.add_argument('--cell_size', type=int, default=config['cell_size'], help='the size of atlas cells in px', required=False)
   parser.add_argument('--n_neighbors', type=int, default=config['n_neighbors'], help='the n_neighbors argument for UMAP')
-  parser.add_argument('--min_dist', type=float, default=config['min_dist'], help='the min_dist argument for umap')
+  parser.add_argument('--min_distance', type=float, default=config['min_distance'], help='the min_distance argument for umap')
   parser.add_argument('--metric', type=str, default=config['metric'], help='the metric argument for umap')
   parser.add_argument('--pointgrid_fill', type=float, default=config['pointgrid_fill'], help='float 0:1 that determines sparsity of jittered distributions (lower means more sparse)')
   parser.add_argument('--copy_web_only', action='store_true', help='update ./output/web without reprocessing data')
